import * as React from 'react'
import * as T from '@tesseract-design/react-common'
import {Container, Editor as MobiledocEditor, MarkupButton, LinkButton} from 'react-mobiledoc-editor'
import styled, {CSSObject} from 'styled-components'

const TOOLBAR_BUTTON_COMMON_STYLES: CSSObject = {
	border: 0,
	backgroundColor: 'transparent',
	padding: 0,
	margin: 0,
	height: '3rem',
	width: '3rem',
	color: 'inherit',
	font: 'inherit',
}

const StyledMarkupButton = styled(MarkupButton)(TOOLBAR_BUTTON_COMMON_STYLES)

const StyledLinkButton = styled(LinkButton)(TOOLBAR_BUTTON_COMMON_STYLES)

const RawInput = styled('textarea')({
	color: 'inherit',
	font: 'inherit',
	padding: 0,
	border: 0,
	backgroundColor: 'transparent',
	outline: 0,
	display: 'block',
	width: '100%',
	resize: 'vertical',
})

const ToolbarBase = styled('div')({
	display: 'flex',
	alignItems: 'center',
	flexWrap: 'wrap',
	margin: '1rem 0',
})

const StyledEditor = styled('div')({
	'> *': {
		outline: 0,
	},
})

const Editor = () => {
	const [hydrated, setHydrated] = React.useState(false)
	React.useEffect(() => {
		setHydrated(true)
	}, [])

	if (hydrated) {
		return (
			<Container>
				<ToolbarBase>
					<StyledMarkupButton
						tag="strong"
					>
						<T.Icon
							name="bold"
						/>
					</StyledMarkupButton>
					<StyledMarkupButton
						tag="em"
					>
						<T.Icon
							name="italic"
						/>
					</StyledMarkupButton>
					<StyledLinkButton>
						<T.Icon
							name="link"
						/>
					</StyledLinkButton>
				</ToolbarBase>
				<StyledEditor>
					<MobiledocEditor />
				</StyledEditor>
			</Container>
		)
	}

	return (
		<RawInput
			rows={20}
		/>
	)
}

export default Editor
