import * as React from 'react'
import Head from 'next/head'
import * as T from '@tesseract-design/react-common'
import {LeftSidebarWithMenu} from '@tesseract-design/viewfinder'
import styled from 'styled-components'
import Link from '../../molecules/Link'
import {Subpage} from '../../../utils/query'
import Note from '../../../models/Note'
import Brand from '../../molecules/Brand'
import NoteLinkContent from '../../molecules/NoteLinkContent'
import Folder from '../../../models/Folder'
import FolderLinkContent from '../../molecules/FolderLinkContent'
import Editor from '../../molecules/Editor'

const SidebarLink = styled(Link)({
	textDecoration: 'none',
})

const CenteredContent = styled(LeftSidebarWithMenu.ContentContainer)({
	height: 'calc(100vh - var(--height-topbar, 4rem) - var(--size-menu, 4rem))',
	display: 'grid',
	placeContent: 'center',
	textAlign: 'center',
	'@media (min-width: 720px)': {
		height: 'calc(100vh - var(--height-topbar, 4rem))',
	},
})

// @ts-ignore
const TitleInput = styled('input')({
	color: 'inherit',
	font: 'inherit',
	fontSize: '3rem',
	padding: 0,
	border: 0,
	backgroundColor: 'transparent',
	fontFamily: 'var(--font-family-headings), sans-serif',
	fontStretch: 'var(--font-stretch-headings, normal)',
	fontWeight: 'var(--font-weight-headings, 400)',
	height: '4rem',
	outline: 0,
	width: '100%',
	display: 'block',
	marginBottom: '1rem',
})

const SidebarTitle = styled('h1')({
	margin: 0,
	lineHeight: '4rem',
})

const TitleContainer = styled(LeftSidebarWithMenu.ContentContainer)({
	display: 'block',
})

const SidebarSubtitle = styled('p')({
	margin: '2rem 0',
})

type Props = {
	subpage: Subpage,
	notes: Note[],
	subfolders: Folder[],
	currentFolder: Folder,
	currentNote?: Note,
}

const NoteView: React.FC<Props> = ({
	subpage,
	notes,
	subfolders,
	currentFolder,
	currentNote,
}) => {
	const APP_NAME = 'Zeichen'

	return (
		<>
			<Head>
				<title>
					{currentNote ? `${currentNote.title} | ${APP_NAME}` : APP_NAME}
				</title>
			</Head>
			<LeftSidebarWithMenu.Layout
				brand={
					<Brand />
				}
				sidebarMenuItems={[
					{
						id: 'notes',
						url: {
							pathname: '/my/notes',
						},
						label: 'Notes',
						icon: (
							<T.Icon
								name="book"
							/>
						),
					},
					{
						id: 'bin',
						url: {
							pathname: '/my/bin'
						},
						icon: (
							<T.Icon
								name="trash2"
							/>
						),
						label: 'Bin',
						secondary: true,
					},
				]}
				sidebarMainOpen={subpage === Subpage.SIDEBAR}
				moreItemsOpen={subpage === Subpage.MORE}
				sidebarMain={
					<>
						{currentFolder && (
							<LeftSidebarWithMenu.SidebarMainContainer>
								<SidebarTitle>
									{currentFolder.name}
								</SidebarTitle>
								{currentFolder.description && (
									<SidebarSubtitle>
										{currentFolder.description}
									</SidebarSubtitle>
								)}
							</LeftSidebarWithMenu.SidebarMainContainer>
						)}
						{subfolders.map(f => (
							<SidebarLink
								href={{
									pathname: '/my/notes',
									query: {
										folderId: f.id,
									},
								}}
							>
								<LeftSidebarWithMenu.SidebarMainContainer>
									<FolderLinkContent
										title={f.name}
									/>
								</LeftSidebarWithMenu.SidebarMainContainer>
							</SidebarLink>
						))}
						{notes.map(n => (
							<SidebarLink
								href={{
									pathname: '/my/notes/[noteId]',
									query: {
										noteId: n.id,
									},
								}}
							>
								<LeftSidebarWithMenu.SidebarMainContainer>
									<NoteLinkContent
										title={n.title}
										subtitle={n.contentVersions[0].createdAt.toString()}
									/>
								</LeftSidebarWithMenu.SidebarMainContainer>
							</SidebarLink>
						))}
					</>
				}
				moreLinkMenuItem={{
					label: 'More',
					icon: (
						<T.Icon
							name="more-horizontal"
						/>
					),
					url: {
						query: {
							subpage: 'more',
						}
					}
				}}
				moreLinkComponent={({ url, icon, label, }) => (
					<Link
						href={url}
					>
						<LeftSidebarWithMenu.MoreSidebarMenuContainer>
							<LeftSidebarWithMenu.MoreSidebarMenuItemIcon>
								{icon}
							</LeftSidebarWithMenu.MoreSidebarMenuItemIcon>
							{label}
						</LeftSidebarWithMenu.MoreSidebarMenuContainer>
					</Link>
				)}
				linkComponent={({ url, icon, label, }) => (
					<Link
						href={url}
					>
						<LeftSidebarWithMenu.SidebarMenuContainer>
							<LeftSidebarWithMenu.SidebarMenuItemIcon>
								{icon}
							</LeftSidebarWithMenu.SidebarMenuItemIcon>
							{label}
						</LeftSidebarWithMenu.SidebarMenuContainer>
					</Link>
				)}
			>
				{!currentNote && (
					<CenteredContent>
						<T.Icon
							name="folder"
							size="4rem"
						/>
						Select a note from the menu.
					</CenteredContent>
				)}
				{currentNote && (
					<>
						<TitleContainer
							as="label"
						>
							<TitleInput
								placeholder="Title"
							/>
						</TitleContainer>
						<LeftSidebarWithMenu.ContentContainer>
							<Editor />
						</LeftSidebarWithMenu.ContentContainer>
					</>
				)}
			</LeftSidebarWithMenu.Layout>
		</>
	)
}

export default NoteView
