import {GetServerSideProps, NextPage} from 'next'
import NoteView from '../../../components/templates/NoteView'
import {QueryFragment, Subpage} from '../../../utils/query'
import Note from '../../../models/Note'
import Folder from '../../../models/Folder'

type Props = {
	subpage: Subpage,
	notes: Note[],
	currentFolder?: Folder,
	subfolders: Folder[],
	currentNote: Note,
}

const Page: NextPage<Props> = ({
	subpage,
	notes,
	currentFolder,
	subfolders,
	currentNote,
}) => {
	return (
		<NoteView
			subpage={subpage}
			notes={notes}
			subfolders={subfolders}
			currentFolder={currentFolder}
			currentNote={currentNote}
		/>
	);
};

export default Page

export const getServerSideProps: GetServerSideProps = async (ctx) => {
	const { [QueryFragment.SUBPAGE]: subpage = '', noteId, } = ctx.query
	const authorUser = {
		id: '0',
		profile: {
			id: '0',
			email: 'hello@example.com',
			links: [],
		},
		username: 'johndoe'
	}
	const notes: Note[] = [
		{
			id: '0',
			title: 'Hello',
			authorUser: authorUser,
			contentVersions: [
				{
					id: '0',
					content: 'Note content',
					createdAt: new Date().toISOString(),
				}
			],
		}
	]
	const subfolders: Folder[] = [
		{
			id: '0',
			name: 'Child Folder',
			description: 'Where we put other notes',
		}
	]
	const currentNote: Note = {
		id: noteId as string,
		title: 'This Note',
		authorUser,
		contentVersions: [],
	}
	return {
		props: {
			subpage,
			notes,
			subfolders,
			currentFolder: {
				name: 'Root Folder',
				description: 'Default location of your notes.',
			},
			currentNote,
		},
	}
}
